<?php

namespace Assetdocs\Demotables\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Demotables\Interfaces\DemotableRepositoryInterface;
use Assetdocs\Demotables\Repositories\Presenter\DemotableItemTransformer;

/**
 * Pubic API controller class.
 */
class DemotableApiController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Assetdocs\Demotable\Interfaces\DemotableRepositoryInterface $demotable
     *
     * @return type
     */
    public function __construct(DemotableRepositoryInterface $demotable)
    {
        $this->middleware('api');

        $this->repository = $demotable;
        parent::__construct();
    }

    /**
     * Show demotable's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $demotables = $this->repository
            ->pushCriteria(new \Assetdocs\Demotables\Repositories\Criteria\DemotablePublicCriteria())
            ->setPresenter('\\Assetdocs\\Demotables\\Repositories\\Presenter\\DemotableListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $demotables['code'] = 2000;
        return response()->json($demotables)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show demotable.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $demotable = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($demotable)) {
            $demotable         = $this->itemPresenter($module, new DemotableItemTransformer);
            $demotable['code'] = 2001;
            return response()->json($demotable)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
